import React, { useEffect, useState } from 'react';
import Image from 'next/image';
import { useRouter } from 'next/router';
import Link from 'next/link';

import { IMAGES } from '../utilities/utils';
import PasswordHeader from '@/components/passwordHeader';
import Modal from '@/components/model';
import { useSelector, useDispatch } from 'react-redux';
import { newPassword } from '@/store/userReducer';
import Loader from './Loader';
import { useTranslation } from 'react-i18next';
import ToggleLanguageButton from '@/components/ToggleLanguageButton';
import i18n from '../../i18n';


const ForgetPassword = () => {
    const { t } = useTranslation();
    const { forgetmsg, newPass, error, loader } = useSelector(state => state.user)
    const dispatch = useDispatch()
    const router = useRouter();
    const [isModalOpen, setIsModalOpen] = useState(false);
    const [passwords, setPasswords] = useState({
        email: forgetmsg?.email ? forgetmsg?.email : '',
        temporaryPassword: '',
        newPassword: '',
        confirmPassword: '',
    });
    const formFields = [
        { label: 'Temporary Password', name: 'temporaryPassword', type: 'password' },
        { label: 'New Password', name: 'newPassword', type: 'password' },
        { label: 'Confirm Password', name: 'confirmPassword', type: 'password' },
    ];
    const [err, setErr] = useState({
        tempPassErr: '',
        newPassErr: '',
        confirmPassErr: ''
    })


    const openModal = () => {
        setIsModalOpen(true);
    };

    const closeModal = () => {
        setIsModalOpen(false);
    };

    const isPasswordValid = (password) => {
        const hasLowercase = /[a-z]/.test(password);
        const hasUppercase = /[A-Z]/.test(password);
        const hasSpecialChar = /[!@#$%^&*]/.test(password);
        const hasNumber = /[0-9]/.test(password);
        const criteriaMet = [hasLowercase, hasUppercase, hasSpecialChar, hasNumber].filter(Boolean).length >= 3;
        return criteriaMet;
    };

    const handleChange = (field, value) => {
        setPasswords((prevPasswords) => ({
            ...prevPasswords,
            [field]: value,
        }));
    };

    const handleSubmit = (e) => {
        e.preventDefault();
        if (!isPasswordValid(passwords.newPassword)) {
            if (passwords.newPassword != passwords.confirmPassword) {
                setErr({
                    tempPassErr: '',
                    newPassErr: t('invaliderror'),
                    confirmPassErr: t('notmatcherror')
                })
            } else {
                setErr({
                    tempPassErr: '',
                    newPassErr: t('invaliderror'),
                    confirmPassErr: ''
                })
            }
            openModal()
        } else if (passwords.newPassword != passwords.confirmPassword) {
            setErr({
                tempPassErr: '',
                newPassErr: '',
                confirmPassErr: t('notmatcherror')
            })
        } else {
            setErr({
                tempPassErr: '',
                newPassErr: '',
                confirmPassErr: ''
            })
            dispatch(newPassword(passwords))
        }

    };

    useEffect(() => {
        if (error?.message == "The temporary password you entered is incorrect, please check your email and enter the temporary password mentioned in the email.") {
            setErr({
                tempPassErr: t('incorrectpassword'),
                newPassErr: '',
                confirmPassErr: ''
            })
        }
    }, [forgetmsg, error])


    return (
        <>
            {loader && <Loader />}
            <div>
                <PasswordHeader />


                <Image alt='logo' src={IMAGES.unlock} className='h-32 mt-[12.5px] mx-auto object-contain w-44' />

                <p className={`text-appBlack ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'} font-normal mx-auto text-[22px]  text-center`}>
                    {t('tempPass1')}<br />{t('tempPass2')}
                </p>

                <form onSubmit={handleSubmit}>
                    {formFields.map((field) => (
                        <div key={field.name} className='flex items-center justify-center'>
                            <div className='flex-col mt-8  w-[378px]'>
                                <p className={`text-appBlack ${i18n.language == 'en' ? 'font-spartan text-[15px]' : 'font-rubik text-[18px]'}  font-normal `}>{t(field.name)}</p>
                                <input
                                    required
                                    type={field.type}
                                    value={passwords[field.name]}
                                    onChange={(e) => handleChange(field.name, e.target.value)}
                                    className='w-full mt-2 rounded-md bg-appOffWhite shadow-md h-[42px] px-2 custom-input'
                                />
                                <p className={`text-appRed ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'}  font-normal text-[11px] mt-2`}>{field.name == 'temporaryPassword' && err.tempPassErr != '' ? err.tempPassErr : field.name == 'newPassword' && err.newPassErr != '' ? err.newPassErr : field.name == 'confirmPassword' && err.confirmPassErr != '' && err.confirmPassErr}</p>
                            </div>
                        </div>
                    ))}

                    <div className='flex my-10 items-center justify-center'>
                        <button
                            type='submit'
                            className={`bg-appSeaGreen w-[134px] h-[59px] bg-4EB9B1 text-white rounded-full text-center text-[22px]  ${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} cursor-pointer`}
                        >
                            {t('create')}
                        </button>
                    </div>
                </form>
            </div>
            <Modal isOpen={isModalOpen} onClose={closeModal}>

                <div className='bg-appRed items-center rounded-t-lg flex justify-center py-6 px-56'>
                    <Image alt='warningimg' className='w-12 h-12 ' src={IMAGES.warning} />
                </div>

                <h1 className={`text-appBlack ${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'}  text-center text-[22px]  mt-5`}>{t('passwordrule')}</h1>

                <p className={`text-appBlack ${i18n.language == 'en' ? 'font-spartan' : 'font-rubik'}  font-normal text-center w-[320px] mx-auto text-[18px] mt-3`}>{t('passwordrulesubtext')}</p>

                <ul className={`list-disc text-appBlack ${i18n.language == 'en' ? 'font-spartan text-[18px]' : 'font-rubik text-[22px]'}  font-normal text-[18px] mx-[120px] mt-6 `}>
                    <li>{t('passrule1')}</li>
                    <li>{t('passrule2')}</li>
                    <li>{t('passrule3')}</li>
                    <li>{t('passrule4')}</li>

                </ul>


                <div className='flex pb-5 mt-8 items-center justify-center'>
                    <button
                        onClick={() => closeModal()}
                        className={`bg-appRed w-[134px] h-[59px] text-white rounded-full text-center text-[22px] font-bold ${i18n.language == 'en' ? 'font-spartan font-bold' : 'font-rubik font-medium'} cursor-pointer`}
                    >
                        {t('accept')}
                    </button>
                </div>

            </Modal>

            <style jsx>
                {`
                .custom-input:focus {
                    border-color: #4EB9B1;
                    outline: none;
                    box-shadow: 0 0 0 2px rgba(78, 185, 177, 0.5);
                }
                `}
            </style>
        </>
    );
};

export default ForgetPassword;
